@@ -1796,7 +1796,7 @@ static void cb(struct gps_data_t* data, char * buf, size_t len, int level)
   }
 
   if ((data->set & SPEED_SET) && !isnan(data->fix.speed)) {
-    gpsData.SetSpeed(data->fix.speed);
+    gpsData.SetSpeed(data->fix.speed/3.6);
   }
 
   if ((data->set & TRACK_SET) && !isnan(data->fix.track)) {
